{{/* vim: set filetype=mustache: */}}
{{/*
Expand the name of the chart.
*/}}
{{- define "px.name" -}}
{{- default .Chart.Name .Values.nameOverride | trunc 63 | trimSuffix "-" -}}
{{- end -}}

{{/*
Create a default fully qualified app name.
We truncate at 63 chars because some Kubernetes name fields are limited to this (by the DNS naming spec).
If release name contains chart name it will be used as a full name.
*/}}
{{- define "px.fullname" -}}
{{- if .Values.fullnameOverride -}}
{{- .Values.fullnameOverride | trunc 63 | trimSuffix "-" -}}
{{- else -}}
{{- $name := default .Chart.Name .Values.nameOverride -}}
{{- if contains $name .Release.Name -}}
{{- .Release.Name | trunc 63 | trimSuffix "-" -}}
{{- else -}}
{{- printf "%s-%s" .Release.Name $name | trunc 63 | trimSuffix "-" -}}
{{- end -}}
{{- end -}}
{{- end -}}

{{/*
Create chart name and version as used by the chart label.
*/}}
{{- define "px.chart" -}}
{{- printf "%s-%s" .Chart.Name .Chart.Version | replace "+" "_" | trunc 63 | trimSuffix "-" -}}
{{- end -}}

{{/*
Compute if the pxl-scripts are enabled.
*/}}
{{- define "px.pxlScriptsEnabled" -}}
{{- $_ := set . "pxlScriptsEnabled" (or
  (eq (.Values.px.enabled | toString) "true")
  (and (eq (.Values.px.enabled | toString) "-") (eq (.Values.global.enabled | toString) "true"))) -}}
{{- end -}}

{{/*
Sets extra px annotations
*/}}
{{- define "px.annotations" -}}
  {{- if .Values.px.annotations }}
      annotations:
        {{- $tp := typeOf .Values.px.annotations }}
        {{- if eq $tp "string" }}
          {{- tpl .Values.px.annotations . | nindent 4 }}
        {{- else }}
          {{- toYaml .Values.px.annotations | nindent 4 }}
        {{- end }}
  {{- end }}
{{- end -}}

{{/*
Compute if the PxL script gauge.kubernetes.conn-stats is enabled.
*/}}
{{- define "pxl.connStatsEnabled" -}}
{{- $_ := set . "connStatsEnabled" (or
  (eq (.Values.scripts.connStats.enabled | toString) "true")
  (and (eq (.Values.scripts.connStats.enabled | toString) "-") (eq (.Values.global.enabled | toString) "true"))) -}}
{{- end -}}

{{/*
Compute if the PxL script gauge.kubernetes.http-events.req-body-size-bytes is enabled.
*/}}
{{- define "pxl.httpRequestEnabled" -}}
{{- $_ := set . "httpRequestEnabled" (or
  (eq (.Values.scripts.httpRequest.enabled | toString) "true")
  (and (eq (.Values.scripts.httpRequest.enabled | toString) "-") (eq (.Values.global.enabled | toString) "true"))) -}}
{{- end -}}

{{/*
Compute if the PxL script gauge.kubernetes.http-events.resp-body-size-bytes is enabled.
*/}}
{{- define "pxl.httpResponseEnabled" -}}
{{- $_ := set . "httpResponseEnabled" (or
  (eq (.Values.scripts.httpResponse.enabled | toString) "true")
  (and (eq (.Values.scripts.httpResponse.enabled | toString) "-") (eq (.Values.global.enabled | toString) "true"))) -}}
{{- end -}}

{{/*
Compute if the PxL script gauge.kubernetes.network-stats is enabled.
*/}}
{{- define "pxl.networkStatsEnabled" -}}
{{- $_ := set . "networkStatsEnabled" (or
  (eq (.Values.scripts.networkStats.enabled | toString) "true")
  (and (eq (.Values.scripts.networkStats.enabled | toString) "-") (eq (.Values.global.enabled | toString) "true"))) -}}
{{- end -}}

{{/*
Compute if the PxL script gauge.kubernetes.process-stats.cpu-usage is enabled.
*/}}
{{- define "pxl.cpuUsageEnabled" -}}
{{- $_ := set . "cpuUsageEnabled" (or
  (eq (.Values.scripts.cpuUsage.enabled | toString) "true")
  (and (eq (.Values.scripts.cpuUsage.enabled | toString) "-") (eq (.Values.global.enabled | toString) "true"))) -}}
{{- end -}}

{{/*
Compute if the PxL script gauge.kubernetes.process-stats.rss-bytes is enabled.
*/}}
{{- define "pxl.rssEnabled" -}}
{{- $_ := set . "rssEnabled" (or
  (eq (.Values.scripts.rss.enabled | toString) "true")
  (and (eq (.Values.scripts.rss.enabled | toString) "-") (eq (.Values.global.enabled | toString) "true"))) -}}
{{- end -}}

{{/*
Compute if the PxL script gauge.kubernetes.process-stats.total-disk-read-throughput-bytes is enabled.
*/}}
{{- define "pxl.diskReadEnabled" -}}
{{- $_ := set . "diskReadEnabled" (or
  (eq (.Values.scripts.diskRead.enabled | toString) "true")
  (and (eq (.Values.scripts.diskRead.enabled | toString) "-") (eq (.Values.global.enabled | toString) "true"))) -}}
{{- end -}}

{{/*
Compute if the PxL script gauge.kubernetes.process-stats.total-disk-write-throughput-bytes is enabled.
*/}}
{{- define "pxl.diskWriteEnabled" -}}
{{- $_ := set . "diskWriteEnabled" (or
  (eq (.Values.scripts.diskWrite.enabled | toString) "true")
  (and (eq (.Values.scripts.diskWrite.enabled | toString) "-") (eq (.Values.global.enabled | toString) "true"))) -}}
{{- end -}}

{{/*
Compute if the PxL script gauge.kubernetes.process-stats.vsize-bytes is enabled.
*/}}
{{- define "pxl.vsizeEnabled" -}}
{{- $_ := set . "vsizeEnabled" (or
  (eq (.Values.scripts.vsize.enabled | toString) "true")
  (and (eq (.Values.scripts.vsize.enabled | toString) "-") (eq (.Values.global.enabled | toString) "true"))) -}}
{{- end -}}

{{/*
Compute if the PxL script summary.kubernetes.dns-events.latency is enabled.
*/}}
{{- define "pxl.dnsLatencyEnabled" -}}
{{- $_ := set . "dnsLatencyEnabled" (or
  (eq (.Values.scripts.dnsLatency.enabled | toString) "true")
  (and (eq (.Values.scripts.dnsLatency.enabled | toString) "-") (eq (.Values.global.enabled | toString) "true"))) -}}
{{- end -}}

{{/*
Compute if the PxL script summary.kubernetes.http-events.latency is enabled.
*/}}
{{- define "pxl.httpLatencyEnabled" -}}
{{- $_ := set . "httpLatencyEnabled" (or
  (eq (.Values.scripts.httpLatency.enabled | toString) "true")
  (and (eq (.Values.scripts.httpLatency.enabled | toString) "-") (eq (.Values.global.enabled | toString) "true"))) -}}
{{- end -}}